# jsonschema_explorer

A simple Python tool to parse a JSON object and explore its schema, displaying the data types in a readable format.

**Note**: This package only analyzes the **first JSON object** in a list of JSON objects. It will display how many JSON objects are in the list with a field called "_length".

## Installation

To install, use pip:

```bash
pip install jsonschema_explorer